@@ -19,7 +19,7 @@ from xml.sax.saxutils import escape, unescape
 import editabletuple
 
 
-__version__ = '1.0.2' # uxf module version
+__version__ = '1.2.0' # uxf module version
 VERSION = 1.0 # UXF file format version
 
 UTF8 = 'utf-8'
@@ -61,18 +61,13 @@ def _validate_format(name, value): # If invalid we return the valid default
                          40 <= value <= 240) else 96
     if name == 'realdp':
         return value if (value is None or 0 <= value <= 15) else None
-    if name == 'max_list_in_line':
-        return value if 1 <= value <= 120 else 10
-    if name == 'max_fields_in_line':
-        return value if 1 <= value <= 120 else 5
     if name == 'max_short_len':
         return value if 24 <= value <= 60 else 32
 
 
 Format = editabletuple.editableobject(
-    'Format', 'indent', 'wrap_width', 'realdp', 'max_list_in_line',
-    'max_fields_in_line', 'max_short_len',
-    defaults=('  ', 96, None, 10, 5, 32), validator=_validate_format,
+    'Format', 'indent', 'wrap_width', 'realdp', 'max_short_len',
+    defaults=('  ', 96, None, 10, 32), validator=_validate_format,
     doc='''Specifies various aspects of how a UXF file is dumped to file or
 to a string.
 `indent` defaults to 2 spaces and may be an empty string or up to 32 spaces
@@ -81,8 +76,6 @@ or 40<=240
 `realdp` defaults to None which means use however many digits after the
 decimal place are needed to represent the given `real` (i.e., Python
 `float`); if not None specify an int 0<=15
-`max_list_in_line` defaults to 10 and must be 1<=120
-`max_fields_in_line` defaults to 5 and must be 1<=120
 `max_short_len` defaults to 32 and must be 24<=60''')
 
 
@@ -758,6 +751,7 @@ class TClass:
         self.ttype = ttype
         self.fields = []
         self.comment = comment
+        self._RecordClass = None
         if fields is not None:
             for field in fields:
                 if isinstance(field, str):
@@ -766,6 +760,23 @@ class TClass:
                     self.fields.append(field)
 
 
+    @property
+    def RecordClass(self):
+        if self._RecordClass is None:
+            self._make_RecordClass()
+        return self._RecordClass
+
+
+    def _make_RecordClass(self):
+        if not self.ttype:
+            raise Error('#340:can\'t use an unnamed table tclass')
+        if not self.fields:
+            raise Error("#350:can't create a table's tclass with no fields")
+        self._RecordClass = editabletuple.editabletuple(
+            f'UXF_{self.ttype}', # prefix avoids name clashes
+            *[field.name for field in self.fields])
+
+
     @property
     def ttype(self):
         return self._ttype
@@ -929,9 +940,9 @@ class Table:
 
     @property
     def RecordClass(self):
-        if self._RecordClass is None:
-            self._make_RecordClass()
-        return self._RecordClass
+        if self.tclass is None:
+            raise Error('#332:table has no tclass')
+        return self.tclass.RecordClass
 
 
     @property
@@ -990,40 +1001,27 @@ class Table:
         return True
 
 
-    def _make_RecordClass(self):
-        if not self.ttype:
-            raise Error('#340:can\'t use an unnamed table')
-        if not self.fields:
-            raise Error('#350:can\'t create a table with no fields')
-        self._RecordClass = editabletuple.editabletuple(
-            f'UXF_{self.ttype}', # prefix avoids name clashes
-            *[field.name for field in self.fields])
-
-
     def _classify(self, row):
         record = self.records[row]
-        RecordClass = self.RecordClass
-        if not isinstance(record, RecordClass):
-            record = self.records[row] = RecordClass(*record)
+        if not isinstance(record, self.RecordClass):
+            record = self.records[row] = self.RecordClass(*record)
         return record
 
 
     def append(self, record):
         '''Appends a record (either a RecordClass tuple or a sequence of
         field values) to the table'''
-        RecordClass = self.RecordClass
-        if not isinstance(record, RecordClass):
-            record = RecordClass(*record)
+        if not isinstance(record, self.RecordClass):
+            record = self.RecordClass(*record)
         self.records.append(record)
 
 
-    def insert(self, index, record):
+    def insert(self, row, record):
         '''Inserts a record (either a RecordClass tuple or a sequence of
-        field values) into the table at the given index position'''
-        RecordClass = self.RecordClass
-        if not isinstance(record, RecordClass):
-            record = RecordClass(*record)
-        self.records.insert(index, record)
+        field values) into the table at the given row position'''
+        if not isinstance(record, self.RecordClass):
+            record = self.RecordClass(*record)
+        self.records.insert(row, record)
 
 
     @property
@@ -1061,6 +1059,18 @@ class Table:
         # else return None
 
 
+    def get(self, row):
+        '''Return the row-th record as a custom class or None if row is out
+        of range.
+
+        If a record is returned it is an object reference to an
+        editabletuple so any changes made to its fields will be reflected in
+        the table.'''
+        if 0 <= row < len(self.records):
+            return self._classify(row)
+        # else: return None
+
+
     def __getitem__(self, row):
         '''Return the row-th record as a custom class.
 
@@ -1071,9 +1081,8 @@ class Table:
 
     def __setitem__(self, row, record):
         '''Replace the row-th record as a custom class'''
-        RecordClass = self.RecordClass
-        if not isinstance(record, RecordClass):
-            record = RecordClass(*record)
+        if not isinstance(record, self.RecordClass):
+            record = self.RecordClass(*record)
         self.records[row] = record
 
 
@@ -1085,11 +1094,10 @@ class Table:
     def __iter__(self):
         if not self.records:
             return
-        RecordClass = self.RecordClass
         for i in range(len(self.records)):
             record = self.records[i]
-            if not isinstance(record, RecordClass):
-                record = self.records[i] = RecordClass(*record)
+            if not isinstance(record, self.RecordClass):
+                record = self.records[i] = self.RecordClass(*record)
             yield record
 
 
@@ -1855,10 +1863,7 @@ class _Writer:
             self._write_close(text, ']')
             return
         text = self._write_open(text)
-        max_list_in_line = self.format.max_list_in_line
-        if len(item) == 1 or (len(item) <= max_list_in_line and
-                              _are_short(self.format.max_short_len,
-                                         *item[:max_list_in_line + 1])):
+        if len(item) == 1 or _are_short(self.format.max_short_len, *item):
             sep = _SEP if prefix and not text.endswith(_SEP) else ''
             self._write_short_list(sep, item)
         else:
@@ -1896,9 +1901,7 @@ class _Writer:
         if len(item) == 1:
             self._write_single_item_map(sep, item)
 
-        elif len(item) <= self.format.max_fields_in_line and _are_short(
-                self.format.max_short_len,
-                *list(item.values())[:self.format.max_list_in_line + 1]):
+        elif _are_short(self.format.max_short_len, *list(item.values())):
             self._write_short_map(sep, item)
         else:
             self.indent += 1
@@ -2139,16 +2142,11 @@ def _is_short(value, format):
         return len(value) <= format.max_short_len
     if is_scalar(value) or len(value) == 1:
         return True
-    if isinstance(value, (list, List)) and (
-            len(value) <= format.max_list_in_line and
-            _are_short(format.max_short_len,
-                       *value[:format.max_list_in_line + 1])):
+    if isinstance(value, (list, List)) and _are_short(format.max_short_len,
+                                                      *value):
         return True
-    if (isinstance(value, (dict, Map)) and
-            len(value) <= format.max_fields_in_line and
-            _are_short(
-                format.max_short_len,
-                *list(value.values())[:format.max_list_in_line + 1])):
+    if isinstance(value, (dict, Map)) and _are_short(
+            format.max_short_len, *list(value.values())):
         return True
     return False
 
